@@ -26,7 +26,7 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.4.1'
+__version__ = '3.4.3'
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -441,15 +441,16 @@ def netScan(port=80, timeout=0.5):
 
 @appendAll
 def netAttack(addr, times):
-	sock = _socket.socket()
-	val1 = ValueWidget('starting')
-	prog = Progress(maxVal=times, msgForm='($VAL/$MAX) $1 $PERC% $MSG', replaces=[['$1', val1]], inline=True)
+	val1 = ValueWidget('starting...')
+	prog = Progress(maxVal=times * 2, msgForm='$1 $PERC% $MSG', replaces=[['$1', val1]], inline=True)
 	for t in range(times):
-		val1.value = 'connecting to ' + str(addr[0]) + ':' + str(addr[1]) + '...'
+		val1.value = 'connecting to ' + str(addr[0]) + ':' + str(addr[1])
+		prog.next()
+		sock = _socket.socket()
 		sock.connect(addr)
-		val1.value = 'disconnecting from ' + str(addr[0]) + ':' + str(addr[1]) + '...'
+		val1.value = 'disconnecting from ' + str(addr[0]) + ':' + str(addr[1])
+		prog.next()
 		sock.close()
-	del sock
 
 @appendAll
 @addBuiltins
